@@ -5,6 +5,8 @@ pip_version <- function(python) {
   if (!file.exists(python))
     return(numeric_version("0.0"))
 
+  local_prefix_python_lib_to_ld_library_path(python)
+
   # otherwise, ask pip what version it is
   command <- "import sys; import pip; sys.stdout.write(pip.__version__)"
   version <- system2(python, c("-c", shQuote(command)), stdout = TRUE, stderr = TRUE)
@@ -25,10 +27,12 @@ pip_install <- function(python,
                         ignore_installed = FALSE,
                         conda = "auto",
                         envname = NULL,
-                        requirements = NULL)
+                        requirements = NULL,
+                        no_user = TRUE)
 {
   # construct command line arguments
-  args <- c("-m", "pip", "install", "--upgrade", "--no-user")
+  args <- c("-m", "pip", "install", "--upgrade",
+            if (no_user) "--no-user")
   if (ignore_installed)
     args <- c(args, "--ignore-installed")
   args <- c(args, pip_options)
@@ -52,9 +56,10 @@ pip_install <- function(python,
       conda <- NULL
   }
 
-  result <- if (is.null(conda) || identical(conda, FALSE))
+  result <- if (is.null(conda) || identical(conda, FALSE)) {
+    local_prefix_python_lib_to_ld_library_path(python)
     system2t(python, args)
-  else
+  } else
     conda_run2(python, args, conda = conda, envname = envname)
 
 
@@ -69,6 +74,7 @@ pip_install <- function(python,
 
 pip_uninstall <- function(python, packages) {
 
+  local_prefix_python_lib_to_ld_library_path(python)
   # run it
   args <- c("-m", "pip", "uninstall", "--yes", packages)
   result <- system2t(python, args)
@@ -84,6 +90,8 @@ pip_uninstall <- function(python, packages) {
 
 pip_freeze <- function(python) {
 
+  local_prefix_python_lib_to_ld_library_path(python)
+
   # run pip freeze to list dependencies
   args <- c("-m", "pip", "freeze")
   output <- system2(python, args, stdout = TRUE)
